function [y,u] = state_reference(Nx,dx,N_tot,dt,c,L,B,Q,R) 

    A = sparse(2*Nx,2*Nx); % Matrix A, containing Finite Difference Discretization of Spatial Laplacian
    A(1:Nx,Nx+1:end) = eye(Nx, Nx);
    A_tmp = zeros(Nx, Nx);
    for ii = 2:Nx-1   
      A_tmp(ii,ii)   = -2*c.^2/(dx.^2);
      A_tmp(ii,ii+1) =    c.^2/(dx.^2);
      A_tmp(ii,ii-1) =    c.^2/(dx.^2);
    end
    A_tmp(1,1) = -2*c.^2/(dx.^2); 
    A_tmp(1,2) = 2*c.^2/(dx.^2); 
    A_tmp(Nx,Nx-1) = 2*c.^2/(dx.^2);
    A_tmp(Nx,Nx) = -2*c.^2/(dx.^2);
    
    A(Nx+1:end,1:Nx) = A_tmp(:,:); 

    K = lqr(A,B,Q,R);

    E = eye(2*Nx,2*Nx);
        
    y = zeros(2*Nx,N_tot);
    for i=1:Nx
        y(i,1) = 3*sin((dx*i*2*pi)/L);
    end

    for tt = 2:N_tot
        y(:,tt) = (E - dt/2*(A-B*K))\((E+dt/2*(A-B*K))*y(:,tt-1));
    end

    u = -K*y;

    % get u on the intermediate points
    for tt = 1:N_tot-1
        u_tmp(tt) = (u(tt)+u(tt+1))/2;
    end

    u = u_tmp;

       